#!/usr/bin/env python3

from pathlib import Path
import numpy as np
import pandas as pd
import matplotlib.pyplot as pt
import json
import tools
import plot


def read_npi_dates(filename):
    """Read NPI dates from file"""
    df = pd.read_csv(filename, parse_dates=[0])
    return (
        list(pd.to_datetime(df['npi_dates']).dt.date),
        list(df['parameter_transfer']),
    )

def plot_cases_incidences(name, filename_results, filename_npi_dates, path=None):
    """Convenience wrapper for plotting cases related things"""
    if path is None:
        path = Path('.')
    df_results = pd.read_csv(path / filename_results, parse_dates=['date'])
    npi_dates, param_trans = read_npi_dates(
        path / filename_npi_dates,
    )

    _, ax = pt.subplots(1, 1)
    plot.cases(
        df_results['date'],
        df_results['I_in'],
        df_results['I_obs'],
        npi_dates,
        param_trans,
        name,
        ax,
        path / f'{name}_cases.png',
    )

    _, ax = pt.subplots(1, 1)
    plot.cases(
        df_results['date'],
        df_results['incidence'],
        df_results['incidence_obs'],
        npi_dates,
        param_trans,
        name,
        ax,
        path / f'{name}_incidences.png',
        incidences=True,
    )

if __name__ == '__main__':
    filename_cfg = tools.cmd_line_name()
    with open(filename_cfg) as f:
        cfg = json.load(f)
    name_focal = cfg['country1']['name']
    name_ref = cfg['country2']['name']
    name_scen = f'{name_focal}-{name_ref} Scenario'
    transfer_risk_aversion = cfg['transfer_risk_aversion']

    names = [name_focal, name_ref, name_scen]
    filenames_results = [f'{n}-results.csv' for n in names]
    filenames_npi_dates = [f'{n}-npi_dates.csv' for n in names]

    path = Path(name_ref)
    if transfer_risk_aversion:
        path = Path(f'{name_ref}-transfer_risk')

    print('Plotting cases and incidences')
    for i, name in enumerate(names):
        plot_cases_incidences(
            name,
            filenames_results[i],
            filenames_npi_dates[i],
            path,
        )
